@@ -33,18 +33,19 @@ from yellowdog_client.model import (
 )
 from yellowdog_client.model.exceptions import InvalidRequestException
 
-from yd_commands.interactive import confirmed
-from yd_commands.load_resources import load_resource_specifications
-from yd_commands.object_utilities import (
+from yd_commands.entity_utils import (
     clear_compute_source_template_cache,
     clear_image_family_search_cache,
     find_compute_requirement_template_id_by_name,
     find_compute_source_template_id_by_name,
-    find_image_family_id_by_name,
+    find_image_family_reference_by_name,
     remove_allowances_matching_description,
 )
+from yd_commands.interactive import confirmed
+from yd_commands.load_resources import load_resource_specifications
 from yd_commands.printing import print_error, print_json, print_log, print_warning
 from yd_commands.settings import (
+    DEFAULT_NAMESPACE,
     NAMESPACE_PREFIX_SEPARATOR,
     RN_ALLOWANCE,
     RN_CONFIGURED_POOL,
@@ -59,6 +60,7 @@ from yd_commands.settings import (
     RN_STRING_ATTRIBUTE_DEFINITION,
 )
 from yd_commands.wrapper import ARGS_PARSER, CLIENT, CONFIG_COMMON, main_wrapper
+from yd_commands.ydid_utils import YDIDType, get_ydid_type
 
 CLEAR_CST_CACHE: bool = False  # Track whether the CST cache needs to be cleared
 CLEAR_IMAGE_FAMILY_CACHE: bool = False  # Track whether the IF cache needs to be cleared
@@ -86,6 +88,7 @@ def create_resources(
             "Dry-run: displaying processed JSON resource specifications. Note:"
             " 'resource' property is removed."
         )
+
     for resource in resources:
         try:
             resource_type = resource.pop("resource")
@@ -142,7 +145,8 @@ def create_compute_source_template(resource: Dict):
     Handles all Source types.
     """
     try:
-        namespace = resource.get("namespace")
+        namespace = resource.get("namespace", DEFAULT_NAMESPACE)
+        resource["namespace"] = namespace
         source = resource.pop("source")  # Extract the Source properties
         source_type = source.pop("type").split(".")[-1]  # Extract Source type
         name = source["name"]
@@ -155,16 +159,17 @@ def create_compute_source_template(resource: Dict):
         clear_image_family_search_cache()
         CLEAR_IMAGE_FAMILY_CACHE = False
 
-    image_id = source.get("imageId")
-    if image_id is not None and not any(
-        [x in image_id for x in ["ydid:image:", "ydid:imggrp:", "ydid:imgfam:"]]
-    ):
-        image_family_id = find_image_family_id_by_name(
+    image_id = source.get("image")
+    if get_ydid_type(image_id) not in [
+        YDIDType.IMAGE_FAMILY,
+        YDIDType.IMAGE_GROUP,
+        YDIDType.IMAGE,
+    ]:
+        image_family_id = find_image_family_reference_by_name(
             client=CLIENT, image_family_name=image_id
         )
         if image_family_id is not None:
             source["imageId"] = image_family_id
-            print_log(f"Replaced imageId name '{image_id}' with ID {image_family_id}")
 
     if ARGS_PARSER.dry_run:
         resource["source"] = source
@@ -181,8 +186,7 @@ def create_compute_source_template(resource: Dict):
     )
 
     # Prepend the namespace when searching for existing templates
-    if namespace is not None:
-        name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
+    name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
 
     # Check for an existing ID
     source_id = find_compute_source_template_id_by_name(CLIENT, name)
@@ -218,7 +222,8 @@ def create_compute_requirement_template(resource: Dict):
     try:
         type = resource.pop("type").split(".")[-1]  # Extract type
         name = resource["name"]
-        namespace = resource.get("namespace")
+        namespace = resource.get("namespace", DEFAULT_NAMESPACE)
+        resource["namespace"] = namespace
     except KeyError as e:
         raise Exception(f"Expected property to be defined ({e})")
 
@@ -235,30 +240,25 @@ def create_compute_requirement_template(resource: Dict):
         clear_compute_source_template_cache()
         CLEAR_IMAGE_FAMILY_CACHE = False
 
-    def _get_images_id(
-        image_str: str, context: Dict, key: str, report: bool = False
-    ) -> int:
+    def _get_images_id(image_str: str, context: Dict, key: str) -> int:
         """
         Helper function to match an image family name into an ID.
         """
-        if not any(
-            [x in image_str for x in ["ydid:image:", "ydid:imggrp:", "ydid:imgfam:"]]
-        ):
-            image_family_id = find_image_family_id_by_name(
+        if get_ydid_type(image_str) not in [
+            YDIDType.IMAGE_FAMILY,
+            YDIDType.IMAGE_GROUP,
+            YDIDType.IMAGE,
+        ]:
+            image_family_id = find_image_family_reference_by_name(
                 client=CLIENT, image_family_name=image_str
             )
             if image_family_id is not None:
                 context[key] = image_family_id
-                if report:
-                    print_log(
-                        f"Replaced Image name '{image_str}' with ID {image_family_id}"
-                    )
                 return 1
         return 0
 
     # Prepend the namespace when searching for existing templates
-    if namespace is not None:
-        name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
+    name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
 
     source_template_substitutions = 0
     source_image_id_substitutions = 0
@@ -266,7 +266,7 @@ def create_compute_requirement_template(resource: Dict):
     # Dynamic templates don't have 'sources'; return '[]'
     for source in resource.get("sources", []):
         template_name_or_id = source["sourceTemplateId"]
-        if "ydid:cst:" not in template_name_or_id:
+        if get_ydid_type(template_name_or_id) != YDIDType.COMPUTE_SOURCE_TEMPLATE:
             template_id = find_compute_source_template_id_by_name(
                 client=CLIENT, name=template_name_or_id
             )
@@ -293,7 +293,7 @@ def create_compute_requirement_template(resource: Dict):
 
     images_id = resource.get("imagesId")
     if images_id is not None:
-        _get_images_id(images_id, resource, "imagesId", report=True)
+        _get_images_id(images_id, resource, "imagesId")
 
     if ARGS_PARSER.dry_run:
         _get_model_object(type, resource)  # Report extras and omissions
@@ -606,12 +606,12 @@ def create_configured_worker_pool(resource: Dict):
     """
     try:
         name = resource["name"]
-        namespace = resource.get("namespace")
+        namespace = resource.get("namespace", DEFAULT_NAMESPACE)
+        resource["namespace"] = namespace
     except KeyError as e:
         raise Exception(f"Expected property to be defined ({e})")
 
-    if namespace is not None:
-        name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
+    name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
 
     try:
         cwp_request = _get_model_object("AddConfiguredWorkerPoolRequest", resource)
@@ -648,7 +648,7 @@ def create_allowance(resource: Dict):
     if type == "SourcesAllowance":
         template_name_or_id = resource.get("sourceCreatedFromId", None)
         if template_name_or_id is not None:
-            if "ydid:cst:" not in template_name_or_id:
+            if get_ydid_type(template_name_or_id) != YDIDType.COMPUTE_SOURCE_TEMPLATE:
                 template_id = find_compute_source_template_id_by_name(
                     client=CLIENT, name=template_name_or_id
                 )
@@ -666,7 +666,10 @@ def create_allowance(resource: Dict):
     elif type == "RequirementsAllowance":
         template_name_or_id = resource.get("requirementCreatedFromId", None)
         if template_name_or_id is not None:
-            if "ydid:crt:" not in template_name_or_id:
+            if (
+                get_ydid_type(template_name_or_id)
+                != YDIDType.COMPUTE_REQUIREMENT_TEMPLATE
+            ):
                 template_id = find_compute_requirement_template_id_by_name(
                     client=CLIENT, name=template_name_or_id
                 )
